@@ -129,6 +129,9 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     return(w)
   })
 
+  ## clean misleading names (names == idx+1 because reference is idx == 1)
+  names(warpingFunctions) <- NULL
+
   ## debug plot
   if (plot) {
     ## non interactive device (pdf, png, ...) available?
@@ -174,9 +177,9 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
       notNA <- !is.na(binnedMass[lIdx[[i+1]]])
 
       if (is.null(givenPlotArgs$main)) {
-        plotArgs$main <- paste("sample ", i, " vs reference\n",
-                               "(matched peaks: ", sum(notNA), "/",
-                               nReference, ")", sep="")
+        plotArgs$main <- paste0("sample ", i, " vs reference\n",
+                                "(matched peaks: ", sum(notNA), "/",
+                                nReference, ")")
       }
 
       if (is.null(givenPlotArgs$sub)) {
