@@ -33,13 +33,7 @@
   y <- c(rep(0, halfWindowSize), y, rep(0, halfWindowSize))
   n <- length(y)
   i <- (halfWindowSize+1):(n-halfWindowSize)
-  return(.C("R_localMaxima",
-            as.double(y),
-            as.integer(n),
-            as.integer(halfWindowSize),
-            output=logical(n),
-            DUP=FALSE, ## we don't change the input vector y
-            PACKAGE="MALDIquant")$output[i])
+  return(.Call("C_localMaxima", y, halfWindowSize)[i])
 }
 
 ## R only: obsolete because too slow and too much memory usage
