@@ -8,15 +8,43 @@
 ## load necessary libraries
 library("MALDIquant")
 
+
 ## load example spectra
 data("fiedler2009subset", package="MALDIquant")
 
+
+## check raw data
+## any empty spectra? (empty spectra are ignored in subsequent baseline
+## correction/peak detection; you could find/remove them by calling
+## findEmptyMassObjects/removeEmptyMassObjects)
+## see ?isEmpty, ?findEmptyMassObjects, ?removeEmptyMassObjects
+any(sapply(fiedler2009subset, isEmpty))
+# FALSE
+
+## any spectra with irregular mass values/intervals? (spectra with
+## missing/filtered mass values/irregular mass intervals may compromise
+## subsequent baseline correction and peak detection.)
+any(!sapply(fiedler2009subset, isRegular))
+# FALSE
+
+## do length of spectra differ? (if they differ you have to adjust the
+## corresponding halfWindowSize in subsequent baseline correction and peak
+## detection.)
+any(length(fiedler2009subset[[1]]) != sapply(fiedler2009subset, length))
+# FALSE
+
+
+## preprocessing
 ## sqrt transform (for variance stabilization)
 spectra <- transformIntensity(fiedler2009subset, sqrt)
 
-## simple 5 point moving average for smoothing spectra
-## (maybe you have to increase halfWindowSize if your data are very noisy)
-spectra <- transformIntensity(spectra, movingAverage, halfWindowSize=2)
+
+## 21 point Savitzky-Golay-Filter for smoothing spectra
+## (maybe you have to adjust the halfWindowSize;
+## you could use a simple moving average instead)
+## see ?savitzkyGolay, ?movingAverage
+spectra <- transformIntensity(spectra, savitzkyGolay, halfWindowSize=10)
+
 
 ## remove baseline
 ## (maybe you have to adjust iterations to your spectra; high resolution
@@ -25,6 +53,7 @@ spectra <- transformIntensity(spectra, movingAverage, halfWindowSize=2)
 ## see ?removeBaseline, ?estimateBaseline
 spectra <- removeBaseline(spectra, method="SNIP", iterations=100)
 
+
 ## run peak detection
 ## (maybe you need to adjust halfWindowSize [decreasing it for high resolution
 ## spectra] and SNR [a higher value increase the True-Positive-Rate but decrease
@@ -32,6 +61,7 @@ spectra <- removeBaseline(spectra, method="SNIP", iterations=100)
 ## see ?detectPeaks, ?estimateNoise
 peaks <- detectPeaks(spectra, method="MAD", halfWindowSize=20, SNR=2)
 
+
 ## align spectra by warping
 ## 1. create reference peaks (could be done automatically by
 ##  determineWarpingFunctions)
@@ -46,9 +76,11 @@ warpingFunctions <- determineWarpingFunctions(peaks, reference=refPeaks,
                                               tolerance=0.002)
 peaks <- warpMassPeaks(peaks, warpingFunctions)
 
+
 ## bin peaks
 peaks <- binPeaks(peaks)
 
+
 ## merge technical replicates
 ## 1. create factors for correct assignment
 nTechRep <- 2
@@ -62,6 +94,7 @@ peaks <- filterPeaks(peaks, labels=samples, minFrequency=1)
 ## 3. merge technical replicates
 peaks <- mergeMassPeaks(peaks, labels=samples, fun=mean)
 
+
 ## prepare for statistical analysis
 ## 1. get cancer/control indices
 filenames <- sapply(peaks, function(x)metaData(x)$file[1])
@@ -75,4 +108,5 @@ peaks <- filterPeaks(peaks, minFrequency=1)
 ## 3. export MassPeaks objects as matrix
 training <- intensityMatrix(peaks)
 
+
 ## 'training' and 'classes' could now used by any statistical tool e.g. sda
