@@ -2,7 +2,7 @@ context("calibrate")
 
 m <- matrix(c(1, 2, 3,
               3, 6, 9), nrow=2, byrow=TRUE,
-            dimnames=list(paste("samples", 1:2, sep=""),
+            dimnames=list(paste0("samples", 1:2),
                           paste("peaks", LETTERS[1:3])))
 
 test_that("calibrate throws errors", {
