@@ -1,4 +1,4 @@
-/* Copyright 2012 Sebastian Gibb
+/* Copyright 2012-2013 Sebastian Gibb
  * <mail@sebastiangibb.de>
  *
  * This file is part of MALDIquant for R and related languages.
@@ -12,16 +12,20 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
  */
 
-#include <R.h>
+#include "MALDIquant.h"
 
+#include <R.h>
+#include <Rinternals.h>
+
+/* TODO: replace int by R_xlen_t in R 3.0.0 */
 int windowMaxIdx(double* x, int start, int end) {
-  int m=start;
-  for (int i=start+1; i<=end; ++i) {
+  int i, m=start;
+  for (i=start+1; i<=end; ++i) {
     if (x[m] < x[i]) {
       m=i;
     }
@@ -29,36 +33,43 @@ int windowMaxIdx(double* x, int start, int end) {
   return(m);
 }
 
-int middle(int pos, int start, int end) {
-  return(pos == (start + end)/2);
-}
-
 /* y = array of double values
- * n = length of y
- * span = half window size
+ * s = half window size
  */
-void R_localMaxima(double* y, int* n, int* span, int* output) {
+SEXP C_localMaxima(SEXP y, SEXP s) {
+  SEXP output;
+  /* TODO: replace by R_xlen_t in R 3.0.0 */
+  int n, q, m, windowSize, i, l, mid;
 
-    int windowSize=*span*2;
+  PROTECT(y=coerceVector(y, REALSXP));
+  n=LENGTH(y);
 
-    int m=windowMaxIdx(y, 0, windowSize);
+  PROTECT(output=allocVector(LGLSXP, n));
 
-    output[m]=m==*span;
+  double* xy=REAL(y);
+  int* xo=LOGICAL(output);
+  memset(xo, 0, n*sizeof(int));
 
-    unsigned int i, l, mid;
+  q=asInteger(s);
+  windowSize=q*2;
+  m=windowMaxIdx(xy, 0, windowSize);
 
-    /* i == rhs; l == lhs; mid == middle pos */
-    for (i=windowSize+1, l=i-windowSize, mid=(l+i)/2; i<*n; ++i, ++mid, ++l) {
-      /* maximum out of window, calculate new maximum in current window */
-      if (m < l) {
-        m=windowMaxIdx(y, l, i);
-      } else if (y[i] > y[m]) {
-        m=i;
-      }
+  xo[m]=m==q;
 
-      if (m == mid) {
-        output[m]=1;
-      }
+  /* i == rhs; l == lhs; mid == middle pos */
+  for (i=windowSize+1, l=i-windowSize, mid=(l+i)/2; i<n; ++i, ++mid, ++l) {
+    /* maximum out of window, calculate new maximum in current window */
+    if (m < l) {
+      m=windowMaxIdx(xy, l, i);
+    } else if (xy[i] > xy[m]) {
+      m=i;
     }
-}
 
+    if (m == mid) {
+      xo[m]=1;
+    }
+  }
+
+  UNPROTECT(2);
+  return(output);
+}
